| computeTEW.SpatRaster | R Documentation |
The computeTEW() function allows computing topographic exposure to wind (TEW)
for each cell of a raster grid for a tropical cyclone or set of tropical cyclones.
## S3 method for class 'SpatRaster'
computeTEW(
profiles,
sts,
dtm,
angle = 6,
threshold = 0,
product = "TEWIntegrated",
verbose = 2,
...
)
profiles |
SpatRaster. Wind speed and direction profiles from |
sts |
StormsList object |
dtm |
SpatRaster of the elevation data (Digital Terrain Model) for a given location |
angle |
numeric. Inflection angle of the wind (in degrees). default is 6°. |
threshold |
numeric. Minimum wind speed threshold (in m/s) requirred to compute exposure. default is 0 |
product |
character vector. Desired output statistics:
|
verbose |
numeric. Whether or not the function should display information about the process and/or outputs. Can be:
|
... |
additional arguments (not used) |
the function returns one layer for topographic exposure to wind (TEW)
for each observation or interpolated observation and each Storm.
The names of the layer follow the following terminology, the name of the storm in capital letters,
"TEW", and the indices of the observation separated by underscores
(e.g., "PAM_TEW_41", ...)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.