| computeTEW.list | R Documentation |
The computeTEW() function allows computing topographic exposure to wind (TEW)
for each points registred in a data.frame for a tropical cyclone or set of tropical cyclones.
## S3 method for class 'list'
computeTEW(profiles, points, dtm, angle = 6, threshold = 0, verbose = 2, ...)
profiles |
list Wind speed and direction profiles from |
points |
data.frame. Consisting of two columns names as "x" (for the longitude) and
"y" (for the latitude), providing the coordinates in decimal degrees of the point locations.
Same as the "points" argument of the |
dtm |
SpatRaster of the elevation data (Digital Terrain Model) for a given location |
angle |
numeric. Inflection angle of the wind (in degrees). default is 6°. |
threshold |
numeric. Minimum wind speed threshold (in m/s) requirred to compute exposure. default is 0 |
verbose |
numeric. Whether or not the function should display information about the process and/or outputs. Can be:
|
... |
additional arguments (not used) |
the function returns a list of data.frame with one additional column for topographic exposure to wind (TEW)
for each observation or interpolated observation and each Storm.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.