plotTemporalTEW: Plotting TEW time series at given point locations

View source: R/plotTEW.R

plotTemporalTEWR Documentation

Plotting TEW time series at given point locations

Description

Plotting TEW time series at given point locations

Usage

plotTemporalTEW(data, storm)

Arguments

data

time series generated with temporalBehaviour with product=TS input first and then computeTEW

storm

list of characters. Storm names. The storm must be available in data input. It can also be a vector of integer corresponding to the indices of storms stored in datainput.

Value

null


StormR documentation built on July 15, 2026, 5:08 p.m.