| computeTEW | R Documentation |
The computeTEW() function allows computing topographic exposure to wind (TEW)
for either:
each cell of a regular grid (i.e., a raster). See computeTEW.SpatRaster documentation.
or
a data.frame with the coordinates of the points of interest,
for a given tropical cyclone or a set of tropical cyclones. See computeTEW.list documentation.
computeTEW(profiles, ...)
profiles |
SpatRaster or list. Wind speed and direction profiles from |
... |
additional arguments depending on the type of |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.