Skip to contents

The computeTEW() function allows computing topographic exposure to wind (TEW) for either:

  1. each cell of a regular grid (i.e., a raster). See computeTEW.SpatRaster documentation. or

  2. a data.frame with the coordinates of the points of interest, for a given tropical cyclone or a set of tropical cyclones. See computeTEW.list documentation.

Usage

computeTEW(profiles, ...)

Arguments

profiles

SpatRaster or list. Wind speed and direction profiles from spatialBehaviour() or temporalBehaviour()

...

additional arguments depending on the type of profiles input