The computeTEW() function allows computing topographic exposure to wind (TEW)
for either:
each cell of a regular grid (i.e., a raster). See
computeTEW.SpatRasterdocumentation. ora data.frame with the coordinates of the points of interest, for a given tropical cyclone or a set of tropical cyclones. See
computeTEW.listdocumentation.
Arguments
- profiles
SpatRaster or list. Wind speed and direction profiles from
spatialBehaviour()ortemporalBehaviour()- ...
additional arguments depending on the type of
profilesinput